@@ -38,11 +38,9 @@ const MimeHandler = imports.ui.mimeHandler;
 const TotemMimeTypes = imports.util.totemMimeTypes;
 const Utils = imports.ui.utils;
 
-function AudioRenderer(args) {
-    this._init(args);
-}
+const AudioRenderer = new Lang.Class({
+    Name: 'AudioRenderer',
 
-AudioRenderer.prototype = {
     _init : function() {
         this.moveOnClick = true;
         this.canFullScreen = false;
@@ -64,8 +62,8 @@ AudioRenderer.prototype = {
         let vbox = new Gtk.Box({ orientation: Gtk.Orientation.VERTICAL,
                                  spacing: 1,
                                  margin_top: 48,
-                                 margin_left: 12,
-                                 margin_right: 12 });
+                                 margin_start: 12,
+                                 margin_end: 12 });
         this._box.pack_start(vbox, false, false, 0);
 
         this._titleLabel = new Gtk.Label();
@@ -237,9 +235,7 @@ AudioRenderer.prototype = {
             this._toolbarPlay.set_icon_name('media-playback-pause-symbolic');
             break;
         default:
-            let iconName =
-            (this._toolbarPlay.get_direction() == Gtk.TextDirection.RTL) ?
-                'media-playback-start-rtl-symbolic' : 'media-playback-start-symbolic';
+            let iconName = 'media-playback-start-symbolic';
             this._toolbarPlay.set_icon_name(iconName);
         }
     },
@@ -271,8 +267,8 @@ AudioRenderer.prototype = {
         this._toolbarPlay.show();
         this._mainToolbar.insert(this._toolbarPlay, 0);
 
-        this._currentLabel = new Gtk.Label({ margin_left: 6,
-                                             margin_right: 3 });
+        this._currentLabel = new Gtk.Label({ margin_start: 6,
+                                             margin_end: 3 });
         let item = new Gtk.ToolItem();
         item.add(this._currentLabel);
         item.show_all();
@@ -301,7 +297,7 @@ AudioRenderer.prototype = {
         item.show_all();
         this._mainToolbar.insert(item, 2);
 
-        this._durationLabel = new Gtk.Label({ margin_left: 3 });
+        this._durationLabel = new Gtk.Label({ margin_start: 3 });
         item = new Gtk.ToolItem();
         item.add(this._durationLabel);
         item.show_all();
@@ -309,7 +305,7 @@ AudioRenderer.prototype = {
 
         return this._toolbarActor;
     },
-}
+});
 
 let handler = new MimeHandler.MimeHandler();
 let renderer = new AudioRenderer();
