@@ -12,9 +12,7 @@
  * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * along with this program; if not, see <http://www.gnu.org/licenses/>.
  *
  * The Sushi project hereby grant permission for non-gpl compatible GStreamer
  * plugins to be used and distributed together with GStreamer and Sushi. This
@@ -27,7 +25,7 @@
 
 #include "sushi-cover-art.h"
 
-#include <musicbrainz3/mb_c.h>
+#include <musicbrainz5/mb5_c.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 G_DEFINE_TYPE (SushiCoverArtFetcher, sushi_cover_art_fetcher, G_TYPE_OBJECT);
@@ -212,43 +210,51 @@ fetch_uri_job (GIOSchedulerJob *sched_job,
                gpointer user_data)
 {
   FetchUriJob *job = user_data;
-  MbQuery query;
-  MbReleaseFilter filter;
-  MbRelease release;
-  MbResultList results;
-  gint results_len = 0, idx;
+  Mb5Metadata metadata;
+  Mb5Query query;
+  Mb5Release release;
+  Mb5ReleaseList release_list;
   gchar *retval = NULL;
+  gchar **param_names = NULL;
+  gchar **param_values = NULL;
 
-  query = mb_query_new (NULL, NULL);
+  query = mb5_query_new ("sushi", NULL, 0);
 
-  filter = mb_release_filter_new ();
-  filter = mb_release_filter_title (filter, job->album);
-  filter = mb_release_filter_artist_name (filter, job->artist);
+  param_names = g_new (gchar*, 3);
+  param_values = g_new (gchar*, 3);
 
-  results = mb_query_get_releases (query, filter);
-  mb_query_free (query);
-  mb_release_filter_free (filter);
+  param_names[0] = g_strdup ("query");
+  param_values[0] = g_strdup_printf ("artist:\"%s\" AND release:\"%s\"", job->artist, job->album);
 
-  if (results)
-    results_len = mb_result_list_get_size (results);
+  param_names[1] = g_strdup ("limit");
+  param_values[1] = g_strdup ("10");
 
-  for (idx = 0; idx < results_len; idx++) {
-    gchar asin[255];
+  param_names[2] = NULL;
+  param_values[2] = NULL;
 
-    release = mb_result_list_get_release (results, idx);
-    mb_release_get_asin (release, asin, 255);
+  metadata = mb5_query_query (query, "release", "", "",
+                              2, param_names, param_values);
 
-    mb_release_free (release);
+  mb5_query_delete (query);
 
-    if (asin != NULL &&
+  if (metadata) {
+    release_list = mb5_metadata_get_releaselist (metadata);
+    int i;
+    int release_list_length = mb5_release_list_size (release_list);
+    for (i = 0; i < release_list_length; i++) {
+      gchar asin[255];
+
+      release = mb5_release_list_item (release_list, i);
+      mb5_release_get_asin (release, asin, 255);
+
+      if (asin != NULL &&
         asin[0] != '\0') {
-      retval = g_strdup (asin);
-      break;
+        retval = g_strdup (asin);
+        break;
+      }
     }
   }
-
-  if (results)
-    mb_result_list_free (results);
+  mb5_metadata_delete (metadata);
 
   if (retval == NULL) {
     /* FIXME: do we need a better error? */
@@ -264,7 +270,8 @@ fetch_uri_job (GIOSchedulerJob *sched_job,
   g_io_scheduler_job_send_to_mainloop_async (sched_job,
                                              fetch_uri_job_callback,
                                              job, NULL);
-
+  g_strfreev (param_names);
+  g_strfreev (param_values);
   return FALSE;
 }
 
@@ -573,87 +580,96 @@ try_fetch_from_amazon (SushiCoverArtFetcher *self)
  * License: GPLv2+ with exception clause, see COPYING
  *
  */
+
 static GdkPixbuf *
 totem_gst_buffer_to_pixbuf (GstBuffer *buffer)
 {
   GdkPixbufLoader *loader;
   GdkPixbuf *pixbuf = NULL;
   GError *err = NULL;
+  GstMapInfo info;
+
+  if (!gst_buffer_map (buffer, &info, GST_MAP_READ)) {
+    GST_WARNING("could not map memory buffer");
+    return NULL;
+  }
 
   loader = gdk_pixbuf_loader_new ();
 
-  if (gdk_pixbuf_loader_write (loader, buffer->data, buffer->size, &err) &&
+  if (gdk_pixbuf_loader_write (loader, info.data, info.size, &err) &&
       gdk_pixbuf_loader_close (loader, &err)) {
     pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
     if (pixbuf)
       g_object_ref (pixbuf);
   } else {
-    g_warning ("could not convert tag image to pixbuf: %s", err->message);
+    GST_WARNING("could not convert tag image to pixbuf: %s", err->message);
     g_error_free (err);
   }
 
   g_object_unref (loader);
+
+  gst_buffer_unmap (buffer, &info);
+
   return pixbuf;
 }
 
-static const GValue *
+static GstSample *
 totem_gst_tag_list_get_cover_real (GstTagList *tag_list)
 {
-  const GValue *cover_value = NULL;
+  GstSample *cover_sample = NULL;
   guint i;
 
   for (i = 0; ; i++) {
-    const GValue *value;
-    GstBuffer *buffer;
-    GstStructure *caps_struct;
+    GstSample *sample;
+    GstCaps *caps;
+    const GstStructure *caps_struct;
     int type;
 
-    value = gst_tag_list_get_value_index (tag_list,
-					  GST_TAG_IMAGE,
-					  i);
-    if (value == NULL)
+    if (!gst_tag_list_get_sample_index (tag_list, GST_TAG_IMAGE, i, &sample))
       break;
 
-    buffer = gst_value_get_buffer (value);
-
-    caps_struct = gst_caps_get_structure (buffer->caps, 0);
+    caps = gst_sample_get_caps (sample);
+    caps_struct = gst_caps_get_structure (caps, 0);
     gst_structure_get_enum (caps_struct,
 			    "image-type",
 			    GST_TYPE_TAG_IMAGE_TYPE,
 			    &type);
     if (type == GST_TAG_IMAGE_TYPE_UNDEFINED) {
-      if (cover_value == NULL)
-        cover_value = value;
+      if (cover_sample == NULL) {
+	/* take a ref here since we will continue and unref below */
+	cover_sample = gst_sample_ref (sample);
+      }
     } else if (type == GST_TAG_IMAGE_TYPE_FRONT_COVER) {
-      cover_value = value;
+      cover_sample = sample;
       break;
     }
+    gst_sample_unref (sample);
   }
 
-  return cover_value;
+  return cover_sample;
 }
 
 GdkPixbuf *
 totem_gst_tag_list_get_cover (GstTagList *tag_list)
 {
-  const GValue *cover_value;
+  GstSample *cover_sample;
 
   g_return_val_if_fail (tag_list != NULL, FALSE);
 
-  cover_value = totem_gst_tag_list_get_cover_real (tag_list);
+  cover_sample = totem_gst_tag_list_get_cover_real (tag_list);
   /* Fallback to preview */
-  if (!cover_value) {
-    cover_value = gst_tag_list_get_value_index (tag_list,
-						GST_TAG_PREVIEW_IMAGE,
-						0);
-  }
+    if (!cover_sample) {
+      gst_tag_list_get_sample_index (tag_list, GST_TAG_PREVIEW_IMAGE, 0,
+				     &cover_sample);
+    }
 
-  if (cover_value) {
+  if (cover_sample) {
     GstBuffer *buffer;
     GdkPixbuf *pixbuf;
 
-    buffer = gst_value_get_buffer (cover_value);
+    buffer = gst_sample_get_buffer (cover_sample);
     pixbuf = totem_gst_buffer_to_pixbuf (buffer);
+    gst_sample_unref (cover_sample);
     return pixbuf;
   }
 
